# Property base class 

All Properties are extending the [Property](ical_library.base_classes.Property) class. Let's first start with the base class and then list all the other properties.

::: ical_library.base_classes.Property
